/*
    Item To OBJ v1.2

    Creates an OBJ file containing points (vertices) that match
    the coordinates of the currently selected items.
    
    Version History:
    v1.0    - Initial release.
    v1.1    - Added an option to flip the Z axis. The reason for this 
            is that the LW OBJ loader seems to do some flipping by
            itself. This counters that behavior.  
    v1.2    - Now uses and parses the getSelect() array rather than 
			using firstSelect() followed by nextSelect().
			- Removed unnecessary loop for creation of coord array.
			- Now closes file after finished writing.
			- Added some error handling and messages.
			- Added NAME and VERSION macros
			- Added optional item name tag for each vertex
			- Added optional 1-point polygon creation to support defunked OBJ import in LW9.5
			
    Use at own risk!
    Feel free to report bugs, request features and otherwise comment!

    Dan Dulberger
    evenflcw@yahoo.com    
*/
@version 2.3
@warnings
@script generic
@define NAME "Item To OBJ"
@define VERSION 1.2

//DEFAULT SETTINGS
flipZ = 1; //Sets the default value for "Flip Z Axis" option. 1=ON, 0=OFF.
tagName = 1; //Adds item names as comment after vertex definition. 1=ON, 0=OFF.
make1PointPolygons = 1; //Adds a 1-point polygon to each point. 1=ON, 0=OFF.

//GLOBAL VARIABLES
c1;


generic
{
    Refresh();
	
    time = Scene().currenttime;
    items = Scene().getSelect();
	
	if(items == nil) {
		error("No items selected!");
		return;
	}


//INTERFACE
    reqbegin(NAME+" v"+VERSION);
    
    c1 = ctlfilename("Filename","*.obj", 60, 0);
    ctlrefresh(c1, "addSuffix");
    
    s1 = ctlsep();

    c2 = ctlcheckbox("Flip Z Axis", flipZ);
	c4 = ctlcheckbox("Make 1-Point Polygons", make1PointPolygons);
	c3 = ctlcheckbox("Tag with Item Names", tagName);
    
    return if !reqpost();

    filename = getvalue(c1);
    flipZ = getvalue(c2);
	make1PointPolygons = getvalue(c4);
	tagName = getvalue(c3);
 
    reqend();

	
//WRITE OBJ
    file = File(filename, "w");

	if( !file || !file.isOpen() ) {
		error("Could not open file: "+filename);
		return;
	}

    filepath = split(filename); 

	//Write file header
    file.writeln("o ", filepath[3], filepath[4]);
    file.nl();

	//Write Vertex list
    file.writeln("# Vertex list");
    file.nl();	
    for(i = 1; i <= items.size(); i++) {
		coord = items[i].getWorldPosition(time);
		if( flipZ )
			coord.z *= -1;
        file.write("v ", coord);
		if( tagName ) 
			file.write("\t# ", items[i].name);
		file.nl();
	}
	
	//Write Polygon list
	if( make1PointPolygons ) {
		file.nl();	
		file.nl();	
		file.writeln("# Face list");
		file.nl();	
		for(i = 1; i <= items.size(); i++) {
			file.writeln("p "+i+"//");
	    }
	}
	
	//Write footer and close 
    file.nl();
	file.nl();
    file.writeln("# End of file");
	file.close();
}


//ADDSUFFIX
addSuffix: value
{
    if(strright(value, 4) != ".obj")
        setvalue(c1, value + ".obj");
}

